==> ukui-session-manager_3.22.0.2.orig.tar.gz: ukui-session-manager-3.22.0.2/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="222"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="224"/>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="226"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="230"/>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="232"/>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="234"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="236"/>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="238"/>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="241"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="242"/>
        <source>confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.ui"/>
        <location filename="../obj-x86_64-linux-gnu/tools/ukui-session-tools_autogen/include/ui_mainwindow.h" line="243"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../tools/main.cpp" line="260"/>
        <source>UKUI session tools, show the shutdown dialog without any arguments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="268"/>
        <source>Switch the user of this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="271"/>
        <source>Hibernate this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="274"/>
        <source>Suspend this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="277"/>
        <source>Logout this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="280"/>
        <source>Restart this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="283"/>
        <source>Shutdown this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="372"/>
        <source>system-monitor</source>
        <translation>系统监视器</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="404"/>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="405"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="406"/>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="407"/>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="408"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="409"/>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="410"/>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="436"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to close this system?</source>
        <translation>同时有多个用户处于登录状态，你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="448"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="449"/>
        <source>confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>(user),ukui-control-center is performing a system update or package installation.</source>
        <translation type="vanished">（用户），系统正在进行升级或软件包安装/卸载相关操作。</translation>
    </message>
    <message>
        <source>(user),yhkylin-backup-tools is performing a system backup or restore.</source>
        <translation type="vanished">（用户），备份还原工具正在进行备份或还原。</translation>
    </message>
    <message>
        <source>For system security,Reboot、Shutdown、Logout and Hibernate are temporarily unavailable.</source>
        <translation type="vanished">为了系统安全，重启、关机、注销和休眠功能暂时不可用。</translation>
    </message>
    <message>
        <source>For system security,Reboot、Shutdown and Hibernate are temporarily unavailable.</source>
        <translation type="vanished">为了系统安全，重启、关机和休眠功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../ukui-session/main.cpp" line="403"/>
        <source>UKUI Session Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source> is block system</source>
        <translation type="vanished">阻止系统</translation>
    </message>
    <message>
        <source> into sleep for reason </source>
        <translation type="vanished">休眠，因为</translation>
    </message>
    <message>
        <source> is block system </source>
        <translation type="vanished">阻止系统</translation>
    </message>
    <message>
        <source>into sleep for reason </source>
        <translation type="vanished">睡眠，因为</translation>
    </message>
    <message>
        <source>Are you sure</source>
        <translation type="vanished">你确定</translation>
    </message>
    <message>
        <source> you want to get system into sleep?</source>
        <translation type="vanished">要让系统进入休眠吗?</translation>
    </message>
    <message>
        <source>Are you sure you want to get system into sleep?</source>
        <translation type="vanished">你确定要让系统进入睡眠吗?</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="63"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="64"/>
        <source>confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <source> is block system into reboot for reason </source>
        <translation type="vanished">阻止系统重启，因为</translation>
    </message>
    <message>
        <source> is block system into shutdown for reason </source>
        <translation type="vanished">阻止系统关机，因为</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="vanished">你确定要重启系统吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to shutdown?</source>
        <translation type="vanished">你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="62"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to close this system?</source>
        <translation>同时有多个用户处于登录状态，你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="84"/>
        <source>System update or package installation in progress,this function is temporarily unavailable.</source>
        <translation>正在进行升级或安装/卸载（相关操作），这个功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="85"/>
        <source>System backup or restore in progress,this function is temporarily unavailable.</source>
        <translation>正在进行系统备份或还原，这个功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="97"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1401"/>
        <source>The following program is running to prevent the system from hibernate!</source>
        <translation>以下程序正在运行，阻止系统进入休眠！</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1404"/>
        <source>The following program is running to prevent the system from suspend!</source>
        <translation>以下程序正在运行，阻止系统进入睡眠！</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1407"/>
        <source>The following program is running to prevent the system from logout!</source>
        <translation>以下程序正在运行，阻止系统注销！</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1410"/>
        <source>The following program is running to prevent the system from reboot!</source>
        <translation>以下程序正在运行，阻止系统重启！</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1413"/>
        <source>The following program is running to prevent the system from shutting down!</source>
        <translation>以下程序正在运行，阻止系统关机！</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1464"/>
        <source>Still Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1466"/>
        <source>Still Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1470"/>
        <source>Still Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1472"/>
        <source>Still Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1488"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="61"/>
        <source>some applications are running and they don&apos;t want you to do this.</source>
        <translation>一些程序正在运行，而且它不希望你继续该操作。</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="63"/>
        <source>Still to do!</source>
        <translation>仍然执行！</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="64"/>
        <source>give up</source>
        <translation>放弃</translation>
    </message>
</context>
</TS>

==> ukui-session-manager_4.0.0.3.orig.tar.gz: ukui-session-manager-4.0.0.3/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <source>Switch User</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="vanished">休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">睡眠</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>confirm</source>
        <translation type="vanished">确认</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../tools/main.cpp" line="292"/>
        <source>UKUI session tools, show the shutdown dialog without any arguments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="300"/>
        <source>Switch the user of this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="303"/>
        <source>Hibernate this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="306"/>
        <source>Suspend this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="309"/>
        <source>Logout this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="312"/>
        <source>Restart this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="315"/>
        <source>Shutdown this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="313"/>
        <source>system-monitor</source>
        <translation>系统监视器</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="343"/>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="344"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="345"/>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="346"/>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="347"/>
        <source>Restart</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="348"/>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="349"/>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="374"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to close this system?</source>
        <translation>同时有多个用户处于登录状态，你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="386"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="387"/>
        <source>confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>(user),ukui-control-center is performing a system update or package installation.</source>
        <translation type="vanished">（用户），系统正在进行升级或软件包安装/卸载相关操作。</translation>
    </message>
    <message>
        <source>(user),yhkylin-backup-tools is performing a system backup or restore.</source>
        <translation type="vanished">（用户），备份还原工具正在进行备份或还原。</translation>
    </message>
    <message>
        <source>For system security,Reboot、Shutdown、Logout and Hibernate are temporarily unavailable.</source>
        <translation type="vanished">为了系统安全，重启、关机、注销和休眠功能暂时不可用。</translation>
    </message>
    <message>
        <source>For system security,Reboot、Shutdown and Hibernate are temporarily unavailable.</source>
        <translation type="vanished">为了系统安全，重启、关机和休眠功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../ukui-session/main.cpp" line="414"/>
        <source>UKUI Session Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source> is block system</source>
        <translation type="vanished">阻止系统</translation>
    </message>
    <message>
        <source> into sleep for reason </source>
        <translation type="vanished">休眠，因为</translation>
    </message>
    <message>
        <source> is block system </source>
        <translation type="vanished">阻止系统</translation>
    </message>
    <message>
        <source>into sleep for reason </source>
        <translation type="vanished">睡眠，因为</translation>
    </message>
    <message>
        <source>Are you sure</source>
        <translation type="vanished">你确定</translation>
    </message>
    <message>
        <source> you want to get system into sleep?</source>
        <translation type="vanished">要让系统进入休眠吗?</translation>
    </message>
    <message>
        <source>Are you sure you want to get system into sleep?</source>
        <translation type="vanished">你确定要让系统进入睡眠吗?</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="62"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="63"/>
        <source>confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <source> is block system into reboot for reason </source>
        <translation type="vanished">阻止系统重启，因为</translation>
    </message>
    <message>
        <source> is block system into shutdown for reason </source>
        <translation type="vanished">阻止系统关机，因为</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="vanished">你确定要重启系统吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to shutdown?</source>
        <translation type="vanished">你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="61"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to close this system?</source>
        <translation>同时有多个用户处于登录状态，你确定要退出系统吗？</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="83"/>
        <source>System update or package installation in progress,this function is temporarily unavailable.</source>
        <translation>正在进行升级或安装/卸载（相关操作），这个功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="84"/>
        <source>System backup or restore in progress,this function is temporarily unavailable.</source>
        <translation>正在进行系统备份或还原，这个功能暂时不可用。</translation>
    </message>
    <message>
        <location filename="../tools/main.cpp" line="96"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1348"/>
        <source>The following program is running to prevent the system from hibernate!</source>
        <translation>以下程序阻止休眠，您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1351"/>
        <source>The following program is running to prevent the system from suspend!</source>
        <translation>以下程序阻止睡眠，您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1354"/>
        <source>The following program is running to prevent the system from logout!</source>
        <translation>以下程序阻止注销，您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1357"/>
        <source>The following program is running to prevent the system from reboot!</source>
        <translation>以下程序阻止重启，您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1360"/>
        <source>The following program is running to prevent the system from shutting down!</source>
        <translation>以下程序阻止关机，您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1419"/>
        <source>Still Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1421"/>
        <source>Still Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1427"/>
        <source>Still Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1429"/>
        <source>Still Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../tools/mainwindow.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="61"/>
        <source>some applications are running and they don&apos;t want you to do this.</source>
        <translation>一些程序正在运行，而且它不希望你继续该操作。</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="63"/>
        <source>Still to do!</source>
        <translation>仍然执行！</translation>
    </message>
    <message>
        <location filename="../tools/powerprovider.cpp" line="64"/>
        <source>give up</source>
        <translation>放弃</translation>
    </message>
</context>
</TS>
